@@ -1,6 +1,6 @@
 /*--------------------------------------------------------------------
  *
- *  Copyright (c) 1991-2024 by the GMT Team (https://www.generic-mapping-tools.org/team.html)
+ *  Copyright (c) 1991-2025 by the GMT Team (https://www.generic-mapping-tools.org/team.html)
  *  See LICENSE.TXT file for copying and redistribution conditions.
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -21,15 +21,15 @@
 
 /* configured options and settings for GMT */
 #define GMT_PACKAGE_VERSION_MAJOR 6
-#define GMT_PACKAGE_VERSION_MINOR 5
+#define GMT_PACKAGE_VERSION_MINOR 6
 #define GMT_PACKAGE_VERSION_PATCH 0
 
-#define GMT_PACKAGE_VERSION "6.5.0"
-#define GMT_PACKAGE_VERSION_WITH_GIT_REVISION "6.5.0"
-#define GMT_BUILD_DATE ""
+#define GMT_PACKAGE_VERSION "6.6.0"
+#define GMT_PACKAGE_VERSION_WITH_GIT_REVISION "6.6.0"
+#define GMT_BUILD_DATE "2025.11.17"
 
 /* URL to the docs on the GMT web server */
-#define GMT_DOC_URL "https://docs.generic-mapping-tools.org/6.5"
+#define GMT_DOC_URL "https://docs.generic-mapping-tools.org/6.6"
 
 /* path to executables/libs */
 #define GMT_BINDIR_RELATIVE "bin"
@@ -48,7 +48,7 @@
 
 /* for running and debugging in /build/gmt/src/build */
 /* #undef SUPPORT_EXEC_IN_BINARY_DIR */
-#define GMT_SHARE_DIR_DEBUG "/build/gmt/src/gmt-6.5.0/share"
+#define GMT_SHARE_DIR_DEBUG "/build/gmt/src/gmt-6.6.0/share"
 #define GMT_USER_DIR_DEBUG "/build/gmt/src/build/share"
 #define GMT_BINARY_DIR_SRC_DEBUG "/build/gmt/src/build/src"
 
